@@ -8,9 +8,9 @@ from django.template import RequestContext
 from django.utils.translation import ugettext as _
 
 def admin_honeypot(request, extra_context=None):
+    if not request.path.endswith('/'):
+        return redirect(request.path + '/', permanent=True)
     path = request.get_full_path()
-    if not path.endswith('/'):
-        return redirect(path + '/', permanent=True)
 
     context = {
         'app_path': path,
@@ -21,6 +21,8 @@ def admin_honeypot(request, extra_context=None):
     }
     context['form'].is_valid()
     context.update(extra_context or {})
+    if len(path) > 255:
+        path = path[:230] +  '...(%d chars)' % len(path)
     if request.method == 'POST':
         failed = LoginAttempt.objects.create(
             username=request.POST.get('username'),
@@ -28,6 +30,7 @@ def admin_honeypot(request, extra_context=None):
             session_key=request.session.session_key,
             ip_address=request.META.get('REMOTE_ADDR'),
             user_agent=request.META.get('HTTP_USER_AGENT'),
+            path=path,
         )
         honeypot.send(sender=LoginAttempt, instance=failed, request=request)
     return render_to_response('admin/login.html', context, context_instance=RequestContext(request))
